Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(3)

Unified Diff: third_party/WebKit/Source/web/WebLocalFrameImpl.h

Issue 2797073002: Move WebTextCheckClient reference from WebViewImpl to WebLocalFrameImpl (Closed)
Patch Set: Tue Apr 4 20:53:35 PDT 2017 Created 3 years, 8 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
Index: third_party/WebKit/Source/web/WebLocalFrameImpl.h
diff --git a/third_party/WebKit/Source/web/WebLocalFrameImpl.h b/third_party/WebKit/Source/web/WebLocalFrameImpl.h
index 2ec2c5c780e3980487d48ec00d7eb6d6a916a066..50351e23e44c6fb04bca24d02bcc14b550d3b5c7 100644
--- a/third_party/WebKit/Source/web/WebLocalFrameImpl.h
+++ b/third_party/WebKit/Source/web/WebLocalFrameImpl.h
@@ -180,6 +180,7 @@ class WEB_EXPORT WebLocalFrameImpl final
bool executeCommand(const WebString&) override;
bool executeCommand(const WebString&, const WebString& value) override;
bool isCommandEnabled(const WebString&) const override;
+ void setTextCheckClient(WebTextCheckClient*) override;
void enableSpellChecking(bool) override;
bool isSpellCheckingEnabled() const override;
void replaceMisspelledRange(const WebString&) override;
@@ -403,6 +404,7 @@ class WEB_EXPORT WebLocalFrameImpl final
static void selectWordAroundPosition(LocalFrame*, VisiblePosition);
TextCheckerClient& textCheckerClient() const;
+ WebTextCheckClient* textCheckClient() const { return m_textCheckClient; }
TextFinder* textFinder() const;
// Returns the text finder object if it already exists.
@@ -424,7 +426,6 @@ class WEB_EXPORT WebLocalFrameImpl final
void setContextMenuNode(Node* node) { m_contextMenuNode = node; }
void clearContextMenuNode() { m_contextMenuNode.clear(); }
-
DECLARE_TRACE();
private:
@@ -501,8 +502,9 @@ class WEB_EXPORT WebLocalFrameImpl final
std::unique_ptr<WebInputMethodControllerImpl> m_inputMethodController;
// Stores the TextCheckerClient which communicates with SpellCheckProvider.
Member<TextCheckerClientImpl> m_textCheckerClient;
+ WebTextCheckClient* m_textCheckClient;
// Oilpan: WebLocalFrameImpl must remain alive until close() is called.
// Accomplish that by keeping a self-referential Persistent<>. It is
@@ -501,8 +502,9 @@ class WEB_EXPORT WebLocalFrameImpl final
std::unique_ptr<WebInputMethodControllerImpl> m_inputMethodController;
- // Stores the TextCheckerClient which communicates with SpellCheckProvider.
+ // Stores the TextCheckerClient to bridge SpellChecker and WebTextCheckClient.
Member<TextCheckerClientImpl> m_textCheckerClient;

Powered by Google App Engine
This is Rietveld 408576698